@@ -59,14 +59,17 @@ class LeaseManager:
 
     @staticmethod
     def autorenew(event, headers, task, lease_seconds):
-        url = '{}/{}:renewLease'.format(API_ROOT, task['name'])
+        url = f'{API_ROOT}/{task["name"]}:renewLease'
         body = {
-            'leaseDuration': '{}s'.format(lease_seconds),
+            'leaseDuration': f'{lease_seconds}s',
             'responseView': 'FULL',
         }
 
         while not event.is_set():
-            time.sleep(lease_seconds / 2)
+            for _ in range(int(lease_seconds // 2) * 10):
+                time.sleep(0.1)
+                if event.is_set():
+                    break
 
             body['scheduleTime'] = task['scheduleTime']
 
